Package: shinyStorePlus
Type: Package
Title: Secure in-Browser and Database Storage for 'shiny' Inputs,
        Outputs, Views and User Likes
Version: 1.6
Authors@R: c(
    person("Obinna", "Obianom", email = "idonshayo@gmail.com", role = c("aut", "cre")))
Maintainer: Obinna Obianom <idonshayo@gmail.com>
Description: Store persistent and synchronized data from 'shiny' inputs within the browser. Refresh 'shiny' applications and preserve user-inputs over multiple sessions. A database-like storage format is implemented using 'Dexie.js' <https://dexie.org>, a minimal wrapper for 'IndexedDB'. Transfer browser link parameters to 'shiny' input or output values. Store app visitor views, likes and followers.
License: MIT + file LICENSE
URL: https://shinystoreplus.obi.obianom.com
BugReports: https://github.com/oobianom/shinyStorePlus/issues
Depends: R (> 3.6)
Imports: shiny, jsonlite, utils, htmltools, shinyWidgets
Suggests: rmarkdown, knitr, qpdf
Encoding: UTF-8
VignetteBuilder: knitr
Language: en-US
LazyData: false
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2025-06-06 07:57:35 UTC; in198
Author: Obinna Obianom [aut, cre]
Repository: CRAN
Date/Publication: 2025-06-06 08:20:02 UTC
Built: R 4.6.0; ; 2026-04-28 21:19:23 UTC; unix
