
server <- function(input, output, session) {
  link2input(
    cd323 = "name",
    datasetbin = "data",
    number1 = "num"
    )

  link2input(
    outputnum = "outt",
    inputtype = "output"
  )

}

